<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xpath-default-namespace="http://www.tei-c.org/ns/1.0" version="2.0">

  <xsl:template match="/">
    <html>
      <head>
        <title>MsP2301</title>
      </head>
      <body>
        <xsl:apply-templates/>
      </body>
    </html>
  </xsl:template>


  <!--teiHeader-->
  <!--標題加大、藍色-->
<xsl:template match="titleStmt">
<h1><xsl:value-of select="title[@xml:lang='zh']"/></h1>
  <h1><xsl:value-of select="title[@xml:lang='en']"/></h1><p/>
  指導老師：<xsl:apply-templates select="principal"/>（馬德偉）<br/>
  參與學生：<xsl:apply-templates select="respStmt/name"/><p/>
  </xsl:template>


  <!--出版資訊-->
  <!--電子版資訊-->
  <xsl:template match="publicationStmt">
【 出版資訊】<br/>
    1. 電子版資訊<br/>
    出版單位：<xsl:apply-templates select="pubPlace"/><br/>
    版權聲明：<xsl:apply-templates select="availability"/><br/>
    數位化日期：<xsl:apply-templates select="date"/><br/>
  </xsl:template>
  
  <!--書本資訊-->
  <xsl:template match="biblStruct">
2. 書本資訊<br/>
    書籍名：<xsl:apply-templates select="monogr/title"/><br/>
    集叢名：<xsl:apply-templates select="series/title"/><br/>
    出版單位：<xsl:apply-templates select="monogr/imprint/publisher"/><br/>
    出版日期：<xsl:apply-templates select="monogr/imprint/date"/><br/>
    ISBN：<xsl:apply-templates select="idno"/><br/>
  </xsl:template>
 
  <!--寫本資訊-->
  <xsl:template match="msIdentifier">
3.  寫本資訊<br/>
    典藏單位：<xsl:apply-templates select="repository"/><br/>
    典藏名稱：<xsl:apply-templates select="msName"/><p/>
  </xsl:template>
  
  
  <!--寫本內容-->
  <xsl:template match="msContents">
    【 寫本內容】<br/>
    <xsl:apply-templates/>
  </xsl:template>
 
  <xsl:template match="msItem">
 Sutra <xsl:value-of select="@n"/><br/>
    頁碼：<xsl:apply-templates select="locus"/><br/>
      經名：<xsl:apply-templates select="title"/><br/>
      經名：<xsl:apply-templates select="bibl/title"/><br/>
    頁碼：<xsl:apply-templates select="bibl/biblScope"/><br/>
  </xsl:template>
  
  
  <!--寫本描述-->
  <xsl:template match="physDesc">【寫本描述】<br/>
    <xsl:value-of select="foliation"/>
    <xsl:value-of select="objectDesc/supportDesc/foliation"/>
    <xsl:value-of select="objectDesc/supportDesc/condition"/>
    <xsl:value-of select="handDesc"/><p/>
  </xsl:template>
  
  <!--history-->
  <xsl:template match="history">【寫本歷史】<br/>
   <xsl:value-of select="origin/p"/>，
    <xsl:value-of select="origin/origDate"/>，
    <xsl:value-of select="origin/origPlace"/>。
    <xsl:value-of select="provenance"/>
    <xsl:value-of select="acquisition"/> <p/>
  </xsl:template>

  <!--"editorialDecl"不出現-->
  <xsl:template match="notesStmt"/>
  <xsl:template match="additional"/>
  <xsl:template match="encodingDesc"/>
  <xsl:template match="editorialDecl"/>
  <xsl:template match="profileDesc"/>
 <!-- <xsl:template match="physDesc"/>-->
  <xsl:template match="extent"/>
 
  <!--在 teiHead 和 text 中做隔線-->
  <xsl:template match="text/body">
   【凡例】<br/> 
    綠色表偈頌，藍色表異體字，紅色表修訂， 粉紅色表刪除、增加。<br/>
    <hr/>
    <xsl:apply-templates/>
  </xsl:template>


  <!--在text 和foot 中做隔線-->
  <xsl:template match="/">
    <xsl:apply-templates/><hr/>
    <xsl:value-of select="//teiHeader/encodingDesc/projectDesc"/><br/> 
    <!--<xsl:value-of select="//teiHeader/fileDesc/publicationStmt/availability"/><br/>-->
  </xsl:template>
 
 
  <!--text-->
  <!--add sutra+自動加序號+fm Sutra(的第一個結點，用descendant)+to Cbeta+open a new page+標體h2-->
  <xsl:template match="div">
    <div>
      <h2>Sutra <xsl:value-of select="substring(@facs,3)"/></h2>
      <xsl:variable name="aaa" select="substring(@facs,2)"/>
      <p>
        <xsl:element name="a">
          <!--<xsl:attribute name="target">_blank</xsl:attribute>-->
          <xsl:attribute name="href">http://w3.cbeta.org/cgi-bin/goto.pl?linehead=T02n0100_p<xsl:value-of select="descendant::lb[@ed='T'][1]/@n"></xsl:value-of></xsl:attribute>
          CBETA</xsl:element> | 
        <xsl:element name="a">
          <xsl:attribute name="href">images/<xsl:value-of select="//facsimile/graphic[@xml:id=$aaa]/@url"/>
          </xsl:attribute> 原始圖檔 </xsl:element>
      </p>
      <xsl:apply-templates/>
    </div>
  </xsl:template>
  <xsl:template match="lb[@ed='PD']">
    <br/>
    <xsl:value-of select="@n"/>
  </xsl:template>

  <!--經題粗體-->
  <xsl:template match="head">
    <b>
      <xsl:apply-templates/>
    </b>
  </xsl:template>

  <!--PD寫本sheet-->
  <xsl:template match="milestone">
    <p/>
    <span style="color:gray">--------------------------------------------- sheet
      ---------------------------------------------</span>
    <br/>
  </xsl:template>

  <!--PD寫本行號-->
  <xsl:template match="//lb[@ed='PD']">
    <br/>P2301-<xsl:value-of select="@n"/>:&#xA0;&#xA0;<xsl:text/>
  </xsl:template>
  
  <!--異體字darkorange-->
  <xsl:template match="reg">
    <span style="color:blue">
      <xsl:apply-templates/>
    </span>
  </xsl:template>

  <!--偈頌+空白字元「&#xA0;」+green-->
  <xsl:template match="l">
    <span style="color:green">
      <xsl:text/>&#xA0;&#xA0;<xsl:apply-templates/>
    </span>
  </xsl:template>
  <!--偈頌+空白字元「&#xA0;」-->
  <xsl:template match="caesura">
    <xsl:text>&#xA0;&#xA0;&#xA0;</xsl:text>
  </xsl:template>

  <!--修訂choice+red+ [大v有 > 有大]-->
  <xsl:template match="sic">
    <span style="color:red">[<xsl:apply-templates/>></span>
  </xsl:template>
  <xsl:template match="corr">
    <span style="color:red"><xsl:apply-templates/>]</span>
  </xsl:template>
  <!-- sic/add不加括號+red-->
  <xsl:template match="sic/add">
    <span style="color:red">
      <xsl:apply-templates/>
    </span>
  </xsl:template>
  <!--校勘【T】不出現-->
  <xsl:template match="rdg"/>

  <!-- del > add-->
  <!-- del字上加橫線+ fuchsia-->
  <xsl:template match="del">
    <span style="color:fuchsia; text-decoration:line-through">
      <xsl:apply-templates/>
    </span>
  </xsl:template>
  <!-- add +括號 + fuchsia-->
  <xsl:template match="add">
    <span style="color:fuchsia">[<xsl:apply-templates/>]</span>
  </xsl:template>

  <!-- gap + 括號 + fuchsia-->
  <xsl:template match="gap">
    <span style="color:fuchsia; font-family:新細明體">○○○○ <xsl:apply-templates/></span>
  </xsl:template>



</xsl:stylesheet>
